# coding=utf-8
from django.db import models
from django.conf import settings
from utils.exceptions import CustomError
from apps.option.models import Option
from apps.agent.models import Store

class ReportCustomer(models.Model):
    NOT_CHECKED = 0
    CHECKED = 1
    REPEAT_REPORT = 2
    STATUS_CHOICES = (
        (NOT_CHECKED, '待审核'),
        (CHECKED, '已分配'),
        (REPEAT_REPORT, '重复报备')
    )

    name = models.CharField(max_length=20, verbose_name=u"姓名")
    tel = models.CharField(max_length=15, verbose_name=u'电话')
    gender = models.PositiveSmallIntegerField(choices=settings.GENDER_CHOICES, verbose_name=u'性别',
                                              default=settings.MALE)
    village = models.CharField(max_length=200, verbose_name=u'小区')
    address = models.CharField(max_length=200, verbose_name=u'地址')
    source = models.ForeignKey(Option, verbose_name=u'来源', related_name='report_customer_source', on_delete=models.PROTECT)
    project = models.ManyToManyField(Option, verbose_name=u'项目', related_name='report_customer_category', editable=False,
                                     null=True,blank=True)
    notes = models.CharField(max_length=500, verbose_name=u"备注", null=True)
    report_status = models.PositiveSmallIntegerField(choices=STATUS_CHOICES, verbose_name=u'报备状态', default=NOT_CHECKED)
    check_user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=u'审核人', related_name='report_customer_check_user',
                                   on_delete=models.PROTECT, null=True)
    check_time = models.DateTimeField(verbose_name=u'审核时间', null=True)
    create_user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=u'添加人', related_name='report_customer_create_user',
                                    editable=False, on_delete=models.PROTECT)
    create_time = models.DateTimeField(verbose_name=u'添加时间', auto_now_add=True, editable=False)
    store = models.ForeignKey(Store, verbose_name=u'门店', related_name='report_customer_store',
                                    editable=False, on_delete=models.PROTECT)

    class Meta:
        db_table = 'report_customer'
        verbose_name = u'客户报备'
        ordering = ['-id']
        default_permissions = ()
        permissions = [
            ('view_report_customer', u'查看'),
            ('add_report_customer', u'添加'),
            ('delete_report_customer', u'删除'),
            ('check_report_customer', u'审核'),
        ]
